# Testing setup

We have setup the test directory to define fixtures for each of the tests in the fixtures directory. These are then imported into conftest so that all of the possible fixtures are available for all tests. This should simplify the testing once you have created your initial fixtures.
